@@ -1,12 +1,11 @@
 use crate::APUB_JSON_CONTENT_TYPE;
-use activitystreams::chrono::Utc;
 use actix_web::HttpRequest;
 use anyhow::anyhow;
 use http::{header::HeaderName, HeaderMap, HeaderValue};
 use http_signature_normalization_actix::Config as ConfigActix;
 use http_signature_normalization_reqwest::prelude::{Config, SignExt};
 use lemmy_utils::LemmyError;
-use log::debug;
+use once_cell::sync::Lazy;
 use openssl::{
   hash::MessageDigest,
   pkey::PKey,
@@ -16,12 +15,11 @@ use reqwest::{Client, Response};
 use serde::{Deserialize, Serialize};
 use sha2::{Digest, Sha256};
 use std::str::FromStr;
+use tracing::debug;
 use url::Url;
 
-lazy_static! {
-  static ref CONFIG2: ConfigActix = ConfigActix::new();
-  static ref HTTP_SIG_CONFIG: Config = Config::new().mastodon_compat();
-}
+static CONFIG2: Lazy<ConfigActix> = Lazy::new(ConfigActix::new);
+static HTTP_SIG_CONFIG: Lazy<Config> = Lazy::new(Config::new);
 
 /// Creates an HTTP post request to `inbox_url`, with the given `client` and `headers`, and
 /// `activity` as request body. The request is signed with `private_key` and then sent.
@@ -44,9 +42,6 @@ pub async fn sign_and_send(
     HeaderValue::from_str(APUB_JSON_CONTENT_TYPE)?,
   );
   headers.insert(HeaderName::from_str("Host")?, HeaderValue::from_str(&host)?);
-  // Need to use legacy timezone because mastodon and doesnt understand any new standards
-  let date = Utc::now().to_rfc2822().replace("+0000", "GMT");
-  headers.insert(HeaderName::from_str("Date")?, HeaderValue::from_str(&date)?);
 
   let response = client
     .post(&inbox_url.to_string())
